This module contains all object types (like the physics tags) that are exposed trough amethyst_physics.
Structs
- Collision
Group - Collision Group which ID can go from 0 to 29 (inclusive)
- Physics
Attachment - This component allows to resolve an
Entitytransformation during the physics sub stepping. - Physics
Garbage Collector - This garbage collector is used to store all the PhysicsTags to whom its associated handle get dropped.
- Physics
Handle - The physics handle is used to track the physics resource lifetime. Indeed you don’t have to care about dropping resources (life a RigidBody or a Shape) because they are automatically cleaned out once all PhysicsHandle to that object are dropped.
Enums
- Physics
Area Tag - This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.
- Physics
Joint Tag - This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.
- Physics
Rigid Body Tag - This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.
- Physics
Shape Tag - This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.
Traits
- Physics
Tag - This trait must be implemented for each structure that want to use the PhysicsHandle.