pub struct PhysicsAttachment<N: PtReal> { /* private fields */ }Expand description
This component allows to resolve an Entity transformation during the physics sub stepping.
Each physics sub step, the RigidBody moves, and if you have an Area attached to it, or a
kinematic body, is it necessary to move it also each sub step, in order to have a correct physics behaviour.
This component is useful only for game play implementation purposes, so it’s not necessary in any way for rendering purposes.
Is necessary to also use the component Parent.