PhysicsHandle

Struct PhysicsHandle 

pub struct PhysicsHandle<T: PhysicsTag> { /* private fields */ }
The physics handle is used to track the physics resource lifetime. Indeed you don’t have to care about dropping resources (life a RigidBody or a Shape) because they are automatically cleaned out once all PhysicsHandle to that object are dropped.

Worth to mention that you can store these handle anywhere, and the GC will always take care of its dropping.

If you need a copy of this resource you can simply use the function clone().

All Physics Servers APIs want to deal directly with the PhysicsTag. Use the method get() to retrieve it. Keep in mind that it’s lifetime is not tracked by the GC, thus is not a replacement of the PhysicsHandle.

Implementations

Source

impl<T: PhysicsTag> PhysicsHandle<T>

pub fn new( tag: T, garbage_collector: Arc<RwLock<PhysicsGarbageCollector>>, ) -> Self

Creates new PhysicsHandle.

This function must be called only by a physics backend.

pub fn get(&self) -> T

Returns the PhysicsTag Keep in mind that this doesn’t alter the resource lifetime in anyway.