Module objects

Module objects 

This module contains all object types (like the physics tags) that are exposed trough amethyst_physics.

Structs

CollisionGroup
Collision Group which ID can go from 0 to 29 (inclusive)
PhysicsAttachment
This component allows to resolve an Entity transformation during the physics sub stepping.
PhysicsGarbageCollector
This garbage collector is used to store all the PhysicsTags to whom its associated handle get dropped.
PhysicsHandle
The physics handle is used to track the physics resource lifetime. Indeed you don’t have to care about dropping resources (life a RigidBody or a Shape) because they are automatically cleaned out once all PhysicsHandle to that object are dropped.

Enums

PhysicsAreaTag
This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.
PhysicsJointTag
This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.
PhysicsRigidBodyTag
This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.
PhysicsShapeTag
This is an opaque ID that is created by a physics server. Create this Opaque ID manually is not safe, for this reason is marked as so.

Traits

PhysicsTag
This trait must be implemented for each structure that want to use the PhysicsHandle.